Computes the gene coefficient matrix using principal component regression. For each gene K, regresses it against principal components derived from all other genes via truncated SVD.
pcNetCoreRcpp(X_std, nComp)A numeric matrix (n_genes x (n_genes - 1)) of regression coefficients.
A standardized numeric matrix (samples x genes), centered and scaled by column.
Number of principal components to use.